# Changelog

## v0.7.22

- This is the first, official, version of Intellibricks. After finishing up all the modules and documentation for the first release, I've hard reset the version numbers to provide a fresh start. Now, all commits/versions will follow the proper semantic version rules. I chose 0.7.22 because It's a special date for me :D
